@@ -1,7 +1,7 @@
 use crate::connector::Connector;
 use crate::document::Document;
-use crate::{Dataset, DataResult};
 use crate::Metadata;
+use crate::{DataResult, Dataset};
 use async_std::io::prelude::WriteExt;
 use async_std::io::ReadExt;
 use async_stream::stream;
@@ -39,9 +39,14 @@ impl Default for Json {
 
 #[async_trait]
 impl Document for Json {
+    /// See [`Document::metadata`] for more details.
     fn metadata(&self) -> Metadata {
         Json::default().metadata.merge(self.metadata.clone())
     }
+    /// See [`Document::set_entry_path`] for more details.
+    fn set_entry_path(&mut self, entry_path: String) {
+        self.entry_path = Some(entry_path);
+    }
     /// See [`Document::read_data`] for more details.
     ///
     /// # Example: Should read the array input data.
@@ -61,7 +66,7 @@ impl Document for Json {
     ///     connector.fetch().await?;
     ///
     ///     let mut dataset = document.read_data(&mut connector).await?;
-    ///     let data = dataset.next().await.unwrap().to_json_value();
+    ///     let data = dataset.next().await.unwrap().to_value();
     ///     let expected_data: Value = serde_json::from_str(json_str)?;
     ///     assert_eq!(expected_data, data);
     ///
@@ -85,7 +90,7 @@ impl Document for Json {
     ///     connector.fetch().await?;
     ///
     ///     let mut dataset = document.read_data(&mut connector).await?;
-    ///     let data = dataset.next().await.unwrap().to_json_value();
+    ///     let data = dataset.next().await.unwrap().to_value();
     ///     let expected_data: Value = serde_json::from_str(json_str).unwrap();
     ///     assert_eq!(expected_data, data);
     ///
@@ -136,7 +141,7 @@ impl Document for Json {
     ///     let expected_data: Value = serde_json::from_str(r#"{"field":"value1"}"#)?;
     ///
     ///     let mut dataset = document.read_data(&mut connector).await?;
-    ///     let data = dataset.next().await.unwrap().to_json_value();
+    ///     let data = dataset.next().await.unwrap().to_value();
     ///     assert_eq!(expected_data, data);
     ///
     ///     Ok(())
@@ -160,7 +165,7 @@ impl Document for Json {
     ///     let expected_data: Value = serde_json::from_str(r#"[{"array1":[{"field":"value1"},{"field":"value2"}]},{"_error":"Entry path '/*/not_found/*' not found."}]"#)?;
     ///
     ///     let mut dataset = document.read_data(&mut connector).await?;
-    ///     let data = dataset.next().await.unwrap().to_json_value();
+    ///     let data = dataset.next().await.unwrap().to_value();
     ///     assert_eq!(expected_data, data);
     ///
     ///     Ok(())
@@ -168,8 +173,6 @@ impl Document for Json {
     /// ```
     #[instrument]
     async fn read_data(&self, connector: &mut Box<dyn Connector>) -> io::Result<Dataset> {
-        info!("Start");
-        
         let mut buf = Vec::new();
         connector.read_to_end(&mut buf).await?;
 
@@ -245,7 +248,6 @@ impl Document for Json {
     /// ```
     #[instrument]
     async fn write_data(&self, connector: &mut dyn Connector, value: Value) -> io::Result<()> {
-        trace!("Start");
         if !connector.inner().is_empty() {
             connector.write_all(b",").await?;
         }
@@ -332,8 +334,6 @@ impl Document for Json {
     /// ```
     #[instrument]
     async fn close(&self, connector: &mut dyn Connector) -> io::Result<()> {
-        info!("Start");
-        
         let remote_len = connector.len().await?;
         let buff = String::from_utf8(connector.inner().to_vec())
             .map_err(|e| io::Error::new(io::ErrorKind::InvalidData, e))?;
